/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

define(["dojo/dom","dojo/on","dijit/registry"], function(dom,on,registry) {

	/**
	 * The server address has been changed
	 */
	function serverAddressChanged(address) {
		window.serverAddress = address;
		localStorage.setItem("serverAddress", serverAddress);
	}
  
	function validateServerAddress(serverAddress) {
		console.log("validateServerAddress->", serverAddress);
		var tmpServerAddress = dojo.byId(serverAddress).value;
		var targetNode = dojo.byId("serverAddressStatus");

		targetNode.innerHTML = "Trying to connect to server " + tmpServerAddress;
		dojo.xhrGet({
			url : "http://" + tmpServerAddress + "/mysurance/index.html",
			sync : false,
			load : function(data) {
				if(""== data.replace(/(^\s*)|(\s*$)/g, "")){
					targetNode.innerHTML = "Host not reachable " + tmpServerAddress;
					return;
				}
				serverAddressChanged(tmpServerAddress);
				targetNode.innerHTML = "Server address set to " + tmpServerAddress;
			},
			error : function(err) {
				console.log(err);
				targetNode.innerHTML = "Host not reachable " + tmpServerAddress;
			},
			timeout : 5000
		});

	}
	
	function setSubscribeStatus(value){
		window.subscribeStatus = value;
		localStorage.setItem("subscribeStatus", value);
	}
	
	
	function updateSubscribeStatus(value){
		setSubscribeStatus(value);
		if(("on"==value) && (!isSubscribed())){
			subscribe();
		}else if(("off"==value) && (isSubscribed())){
			unsubscribe();
		}
	}
	
	function isSubscribed(){
		//alert(WL.Client.Push.isSubscribed('mysurancePush'));
		return WL.Client.Push.isSubscribed('mysurancePush');
	}
	
	function subscribe(){
		WL.Client.Push.subscribe("mysurancePush", {
			onSuccess: pushSubscribe_Success_Callback,
			onFailure: pushSubscribe_Fail_Callback
		});
	}

	function unsubscribe(){
		WL.Client.Push.unsubscribe("mysurancePush", {
			onSuccess: pushUnsubscribe_Success_Callback,
			onFailure: pushUnsubscribe_Fail_Callback
		});
	}
	
	function pushSubscribe_Success_Callback(response){
		alert("Subscribe success");
	}
	
	function pushSubscribe_Fail_Callback(response){
		alert("Subscribe failed");
	}

	function pushUnsubscribe_Success_Callback(response){
		alert("unSubscribe success");
	}
	
	function pushUnsubscribe_Fail_Callback(response){
		alert("unSubscribe failed");
	}
	
  
	return {
		init: function() {
			//console.log("Initialize serviceConfig");
			var subsSwitch = registry.byId("subsSwitch");
			if (serverAddress) {
				dom.byId("serverAddr").value = serverAddress;
			}
			if (subscribeStatus){
				switch(subscribeStatus){
					case "on": 
						subsSwitch.set("value", "on");
						break;
					case "off": 
						subsSwitch.set("value", "off");
						break;
					default:
						alert("Wrong subscribe status!");
				}
			}
			
			on(registry.byId("serverAttrBtn").domNode, "click", function(){
			 	validateServerAddress('serverAddr');
			 	updateSubscribeStatus(subsSwitch.value);
			});
		}
	};
});