/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

define("mysurance/widgets/GoogleMap", [ "dojo", "dijit", "dijit/_Widget","mysurance/common" ], function(dojo, dijit, _Widget,common) {
	dojo.declare("mysurance.widgets.GoogleMap", [dijit._Widget],{
	
		mapNode : null,
		initialized : false,
		reqtype : "",
		reqname : "",
		map : null,
		shouldResize : false,
		
		/**
		* Called on initial setup
		*/
		postCreate : function(){
			WL.Logger.debug("GoogleMap.postCreate()");
			var par_wid = dijit.byId(this.domNode.parentNode.id);
			dojo.connect(par_wid, "onBeforeTransitionIn", this, this.setupMap);
			dojo.connect(par_wid, "onBeforeTransitionIn", this, this.checkResize);
			this.mapNode = dojo.create("DIV", {id:"mapContent",className:"map"}, this.domNode);
			if(/android/i.test(navigator.userAgent)){
				this.mapNode.style.height = window.innerHeight - 60 + "px";
			}else{
				this.mapNode.style.height = window.innerHeight - 27 + "px";
			}
		},
		
		/**
		* Attempt to resize the map if needed
		*/	
		checkResize : function(){
			WL.Logger.debug("GoogleMap.checkResize()");
			if(this.shouldResize && this.map){
				this.shouldResize = false;
				google.maps.event.trigger(this.map, 'resize');
			}
		},
		
		/**
		* Called on first load
		* Download and display the map
		*/	
		setupMap : function(){				
			WL.Logger.debug("GoogleMap.setupMap()");
			if(!common.isConnect()){
				alert("can not perform this action in offline mode.");
				return;
			}
			if(this.initialized){
				return;
			}
			this.initialized = true;
			
			var mapNode = this.mapNode;
			
			if(this.reqtype != ""){
				request = { types : [this.reqtype] };
			}else{
				request = { name : this.reqname };
			}
			
			var widget = this;
			// getLocation is defined in utils.js
			getLocation(function(loc){
				WL.Logger.debug("GoogleMap.setupMap().getLocation loc="+loc);
				var radius = 10000;
				
				widget.map = new google.maps.Map(mapNode, {
					mapTypeId: google.maps.MapTypeId.ROADMAP,
					center: loc,
					zoom: (typeof PHONE == 'undefined' || PHONE) ? 11 : 12,
					panControl: false,
					zoomControl: true,
					mapTypeControl: true,
					scaleControl: true,
					streetViewControl: true,
					overviewMapControl: false,
					zoomControlOptions: {
						style: google.maps.ZoomControlStyle.SMALL
					}
				});
				
				dojo.connect(document, "orientationchange", function(){
					//wait for orientation change to complete before resizing
					setTimeout(function(){
						widget.shouldResize = true;
						google.maps.event.trigger(widget.map, 'resize');
						if(document.getElementById("mapContent")){
				  			if(/android/i.test(navigator.userAgent)){
								document.getElementById("mapContent").style.height = window.innerHeight - 60 + "px";
							}else{
								document.getElementById("mapContent").style.height = window.innerHeight - 27 + "px";
							}
				  		}
					}, 50);
				}, false);
				
				//add a marker for user location
				var marker = new google.maps.Marker({
					map: widget.map,
					position: loc,
					icon: 'images/arrow.png',
					shadow: 'images/arrowshadow.png'
				});
				
				//fill user marker with address
				var geocoder = new google.maps.Geocoder();
				geocoder.geocode({'latLng':loc}, function(results, status){
					if(status == google.maps.GeocoderStatus.OK){
						google.maps.event.addListener(marker, 'click', function(){
							infowindow.setContent("<b>Location</b><br>"+results[0].formatted_address.replace(", ", "<br>"));
							infowindow.open(widget.map, this);
						});		
					}
				});
		
				request.location = loc;
				request.radius = radius;
				infowindow = new google.maps.InfoWindow();
				service = new google.maps.places.PlacesService(widget.map);
				WL.Logger.debug("GoogleMap.setupMap().getLocation searching, request="+JSON.stringify(request));
				service.search(request, onLoadPlaces);
			});
			
			
			function onLoadPlaces(results, status) {
				if (status == google.maps.places.PlacesServiceStatus.OK) {
					WL.Logger.debug("GoogleMap.onLoadPlaces() status OK, "+results.length+" places found");
					for (var i = 0; i < results.length; i++) {
						var place = results[i];
					
						//load info
						var inforequest = { reference : place.reference };
						service.getDetails(inforequest, onLoadInfo);
					}
				}else if(status == google.maps.places.PlacesServiceStatus.ZERO_RESULTS){
					WL.Logger.debug("GoogleMap.onLoadPlaces() status ZERO_RESULTS");
					//no results found; expand search
					if(request.radius < 1000000){
						request = {
							location: request.location,
							radius: request.radius*2,
							types: request.types,
							name: request.name
						};
						WL.Logger.debug("GoogleMap.onLoadPlaces() searching again, request="+JSON.stringify(request));
						service.search(request, onLoadPlaces);		
					}
				}
			};
			
			function onLoadInfo(place, status){
				WL.Logger.debug("GoogleMap.onLoadInfo()");
				//filter non-numeric characters out of the phone number
				var number = place.formatted_phone_number;
				var filteredNumber = "";
				if(number){
					var acceptedValues = "0123456789";
					for(var i = 0; i < number.length; i++){
						var c = number.charAt(i);
						if(acceptedValues.indexOf(c)>-1)
							filteredNumber += c;
					}
				}
				
				if (status == google.maps.places.PlacesServiceStatus.OK) {
					//create the marker
					var placeLoc = place.geometry.location;
					var marker = new google.maps.Marker({
						map: widget.map,
						position: new google.maps.LatLng(placeLoc.lat(), placeLoc.lng()),
					});
					google.maps.event.addListener(marker, 'click', function() {
						infowindow.setContent("<b>" + place.name + "</b><br>" + place.formatted_address.replace(", ", "<br>") + (number ? "<br><phonenumber><a href=\"tel:" + filteredNumber + "\">" + place.formatted_phone_number + "</a></phonenumber>" : ""));
						infowindow.open(widget.map, this);
					});
				}
			};
		}
		
	});
});