/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*/

package com.ibm.impact.demo.persistence;

import java.util.HashMap;
import java.util.Map;

import com.ibm.impact.demo.beans.ImpactBeanType;

/**
 * This class provides an in memory implementation of a persistent data store.
 */
public class InMemoryPersistenceLayer implements PersistenceLayer{
	
	Map<String, ImpactBeanType> persistentStore = new HashMap<String, ImpactBeanType>();
	
	/* (non-Javadoc)
	 * @see com.ibm.impact.demo.PersistenceLayer#createEntry(com.ibm.impact.demo.beans.ImpactBeanType)
	 */
	public ImpactBeanType createEntry(String uniqueId, ImpactBeanType type){
		return persistentStore.put(uniqueId, type);
		
	}
	
	/* (non-Javadoc)
	 * @see com.ibm.impact.demo.PersistenceLayer#updateEntry(com.ibm.impact.demo.beans.ImpactBeanType)
	 */
	public ImpactBeanType updateEntry(String uniqueId, ImpactBeanType type){
		return persistentStore.put(uniqueId, type);
	}
	
	/* (non-Javadoc)
	 * @see com.ibm.impact.demo.PersistenceLayer#getEntry(java.lang.String)
	 */
	public ImpactBeanType getEntry (String id){
		return persistentStore.get(id);
		
	}
	
	/* (non-Javadoc)
	 * @see com.ibm.impact.demo.PersistenceLayer#getEntries()
	 */
	public Map<String, ImpactBeanType> getEntries() {
		return persistentStore;
	}
	
	/* (non-Javadoc)
	 * @see com.ibm.impact.demo.PersistenceLayer#deleteEntry(java.lang.String)
	 */
	public ImpactBeanType deleteEntry(String id){
		return persistentStore.remove(id);
	}

}
