/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*/

package com.ibm.impact.demo.persistence;

import java.util.Map;
import com.ibm.impact.demo.beans.ImpactBeanType;

/**
 * This interface defines the APIs exposed when accessing data which has been
 * persisted in some way (in memory, database, etc).  Each persisted object
 * implements a common MysuranceBeanType interface, and is represented by 
 * a unique identifier.
 */
public interface PersistenceLayer {

	/**
	 * Create an entry in the persistent data store.
	 * 
	 * @param id - Unique identifier for the provided object.
	 * @param type - The object to be stored.
	 * @return - The object that was stored as a result of this method's execution.
	 */
	public abstract ImpactBeanType createEntry(String id, ImpactBeanType type);

	/**
	 * Update an entry in the persistent data store.
	 * 
	 * @param id - Unique identifier for the provided object.
	 * @param type - The object to be updated.
	 * @return - The object that was updated as a result of this method's execution.
	 */
	public abstract ImpactBeanType updateEntry(String id, ImpactBeanType type);

	/**
	 * Fetch an object from the persistent data store.
	 * 
	 * @param id - Unique identifier for the provided object.
	 * @return - The object representing the provided id, found in the store.
	 */
	public abstract ImpactBeanType getEntry(String id);
	
	/**
	 * Fetch the full set of entries in the persistent data store.
	 * 
	 * @return - The contents of the data store in a Map.
	 */
	public abstract Map<String, ImpactBeanType> getEntries();

	/**
	 * Delete and entry from the persistent data store.
	 * 
	 * @param id - Unique identifier for the object to be deleted.
	 * @return - The object that was deleted from the store.
	 */
	public abstract ImpactBeanType deleteEntry(String id);

}